@@ -17,7 +17,7 @@ This flask server load all applications declared under
 """
 
 from flask import Flask
-from werkzeug.wsgi import DispatcherMiddleware
+from werkzeug.middleware.dispatcher import DispatcherMiddleware
 from eoleflask.loader import get_apps_list
 
 apps = get_apps_list()
